/*=========================================================================                                                                               
Program:   bbtk
Module:    $RCSfile$
Language:  C++
Date:      $Date$
Version:   $Revision$
=========================================================================*/

/* ---------------------------------------------------------------------

* Copyright (c) CREATIS-LRMN (Centre de Recherche en Imagerie Medicale)
* Authors : Ricardo A Corredor, Eduardo Davila, Laurent Guigues, Jean-Pierre Roux
*
*  This software is governed by the CeCILL-B license under French law and 
*  abiding by the rules of distribution of free software. You can  use, 
*  modify and/ or redistribute the software under the terms of the CeCILL-B 
*  license as circulated by CEA, CNRS and INRIA at the following URL 
*  http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html 
*  or in the file LICENSE.txt.
*
*  As a counterpart to the access to the source code and  rights to copy,
*  modify and redistribute granted by the license, users are provided only
*  with a limited warranty  and the software's author,  the holder of the
*  economic rights,  and the successive licensors  have only  limited
*  liability. 
*
*  The fact that you are presently reading this means that you have had
*  knowledge of the CeCILL-B license and that you accept its terms.
* ------------------------------------------------------------------------ */                                                                         

/****
* Design and Developpement of BBTK GEditor
* Ricardo A Corredor J <ra.corredor67@uniandes.edu.co>
* RaC - 2010
****/

#ifndef __GBlackBoxModel_h__
#define __GBlackBoxModel_h__

//Includes same project
#include "GlobalConstants.h"
#include "GBoxModel.h"

//Includes creaMaracasVisu

//Includes std
#include <iostream>


namespace bbtk
{

	class GBlackBoxModel : public GBoxModel
 	{

	public: 

		//Constructors
		GBlackBoxModel();
		~GBlackBoxModel();
		
		//Public methods

		// The black box has an specific package (important to search in the list with the BBTK Interpreter)
		std::string getBBTKPackage();
		void setBBTKPackage(std::string obpackage);

		// Text in the status bar
		virtual std::string getStatusText();

		// Method to write the information of the black box to be saved in the parameter string
		virtual void save(std::string &content);

		// Is the black box executable or not
		bool isExecutable();
		void setExecutable(bool executable);

		// Set 'value' to the port in position 'pos'
		void setValueToInputPort(int pos,std::string value);
		
		// Set 'value' to the port with name 'name'
		void setValueToInput(std::string name,std::string value);

		// Get the value of the port in position 'pos'
		std::string getValueInputPort(int pos);

		// Get the value of the port with name 'name'
		std::string getValueInput(std::string name);

		// Get id's of the connected inputs 
		std::vector<int> getConnectedInputs();
		// Get id's of the connected outputs
		std::vector<int> getConnectedOutputs();

	private:

		//Private Attributes
		bool _isExecutable;

		//Private Methods

	protected:
		//Protected Attributes
		std::string _bbtkPackage;

		//Protected methods
		
	};


}
// namespace bbtk
#endif

